#!/usr/bin/python -tt
#
# Van Assche Alphonse <alcapcom@gmail.com>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from xselector import XselectorError
from xselector import Xselector
import sys
import commands

import os
import pygtk
pygtk.require("2.0")
import gtk
import gtk.glade
from rhpl.translate import _, N_

# the path must end with /
APP_PATH = "/usr/share/system-config-xselector/"
ICON_PATH = APP_PATH + "pixmaps/system-config-xselector.png"
GLADE_FILE = "system-config-xselector.glade"
I18N_DOMAIN = "system-config-xselector"

class XselectorDialog:
    
    def __init__(self, isVerbose = False):
        self.selector = Xselector(isVerbose)
        self.xmlfn = APP_PATH + GLADE_FILE
        self.mainDialog = gtk.glade.XML(self.xmlfn, "dialogGlxServer", domain=I18N_DOMAIN)
        self.dialogGlxServer = self.mainDialog.get_widget("dialogGlxServer")
        self.buttonEnableAiglx = self.mainDialog.get_widget("buttonEnableAiglx")
        self.buttonEnableXgl = self.mainDialog.get_widget("buttonEnableXgl")
        self.buttonDisableAll = self.mainDialog.get_widget("buttonDisableAll")
        self.buttonDisableGnomeAnim = self.mainDialog.get_widget("buttonDisableGnomeAnim")
        self.applyButton = self.mainDialog.get_widget("applyButton")
        self.closeButton = self.mainDialog.get_widget("closeButton")
        self._initGui()
        self._connectSignals()
        try:
           iconPixbuf = gtk.gdk.pixbuf_new_from_file(ICON_PATH)
           self.dialogGlxServer.set_icon(iconPixbuf)
        except:
            pass
   
    def _connectSignals(self):
        self.applyButton.connect("clicked", self._apply)
        self.closeButton.connect("clicked", self._cancel)
        self.dialogGlxServer.connect("delete_event", self._cancel)
        self.buttonDisableGnomeAnim.connect("clicked", self._disableGnomeAnim)
        
    
    def _initGui(self):
        currentConf = self.selector.getCurrentConfig()
        if currentConf == "aiglx":
            self.buttonEnableAiglx.activate()
        elif currentConf == "xgl":
            self.buttonEnableXgl.activate()
        else:
            self.buttonDisableAll.activate() 
        
    def _apply(self, *args):
        try:
            if self.buttonEnableAiglx.get_active():
                self._enableAiglx()
            if self.buttonEnableXgl.get_active():
                self._enableXgl()
            if self.buttonDisableAll.get_active():
                self._disableGlxStuff()
            self._confimation()
        except XselectorError, (errMsg):
            errorDialog = gtk.MessageDialog(self.dialogGlxServer,
                 type = gtk.MESSAGE_ERROR, buttons = gtk.BUTTONS_CLOSE,
                 message_format = str(errMsg))
            errorDialog.set_title(_("Error Dialog"))
            errorDialog.run()
            errorDialog.destroy()
            self._initGui()
 
    def _cancel(self, *args):
        gtk.main_quit()
        sys.exit(0)
   
 
    def _enableAiglx(self):
        self.selector.enableAiglx()
    
    def _enableXgl(self):
        self.selector.enableXgl()
    
    def _disableGlxStuff(self):
        self.selector.disableAllGlxStuff()
        
    def _confimation(self):
        info = gtk.MessageDialog(self.dialogGlxServer,
             type = gtk.MESSAGE_INFO, 
             buttons = gtk.BUTTONS_CLOSE,
             message_format = _("Configuration apply with sucess! \n\n The changes will be effective at the next X session!\nIf You use GDM as Display Manager you must restart it with <b>gdm-restart</b>"))
        info.set_title(_("Information Dialog"))
        info.run()
        info.destroy()
    
### USER DIALOG QUICK HACK ###
    
    def _disableGnomeAnim(self, *args):
        dialogXml = gtk.glade.XML(self.xmlfn, "dialogDisableGnomeAnim", domain=I18N_DOMAIN)
        # Get the widgets
        self.dialogDisableGA = dialogXml.get_widget("dialogDisableGnomeAnim")
        self.applyUserSelection = dialogXml.get_widget("applyUserSelection")
        self.cancelUserSelection = dialogXml.get_widget("cancelUserSelection")
        self.comboSelectedUser = dialogXml.get_widget("comboboxUsers")
        self.rbuttonSelectedUser = dialogXml.get_widget("radiobuttonSelectedUser")
        # Connect signals
        self.applyUserSelection.connect("clicked", self._applyDisableGA)
        self.cancelUserSelection.connect("clicked", self._cancelDisableGA)        
        # Get the users list
        self.users = commands.getoutput("awk -F: '$3 >= 500  {print $1}' /etc/passwd")
        store = gtk.ListStore(str)
        # Populate the combobox
        for user in self.users.split("\n"):
            store.append([user])
        self.comboSelectedUser.set_model(store)
        self.comboSelectedUser.set_text_column(0)
        self.comboSelectedUser.set_active(0)
        
    def _applyDisableGA(self, *args):
        model = self.comboSelectedUser.get_model()
        index = self.comboSelectedUser.get_active()
        if self.rbuttonSelectedUser.get_active():
            selectedUser = model[index][0]
            self._disableGAForUser(selectedUser)
        else:
            for user in self.users.split("\n"):
                self._disableGAForUser(user)
        self.dialogDisableGA.hide()
    
    def _cancelDisableGA(self, *args):
        self.dialogDisableGA.hide()
    
    def _disableGAForUser(self, username):
            os.system('su %s -c "gconftool-2 -t boolean -s /desktop/gnome/interface/enable_animations false"' % username)
            os.system('su %s -c "gconftool-2 -t boolean -s /apps/panel/global/enable_animations false"' % username)

